@@ -1,7 +1,7 @@
 =begin
 =class NumRu::GDir
 
-A directory service of GPhys.
+A class to represent diretories and data files for GPhys.
 
 ==Overview
 
@@ -18,6 +18,9 @@ outside the root directory is prohibited.  Furthermore, it has a
 working directory as a class variable, whose initial value is the top
 directory and can be changed by ((<GDir.cd>)).
 
+NEW(2005/06): Now GDir can accept DODS URL as a path. Also,
+the top directory can be set to a DODS URL.
+
 ==Class Methods
 
 ---GDir.top=(top)
@@ -124,9 +127,7 @@ directory and can be changed by ((<GDir.cd>)).
 ---GDir.list_data_v
 ---GDir.list_texts
 ---GDir.list_texts_v
----GDir.show
 ---GDir.ls
----GDir.show_v
 ---GDir.ls_v
 
     All of these are dispatched to the current working directory.
@@ -236,7 +237,7 @@ directory and can be changed by ((<GDir.cd>)).
 ---list_dirs(path=nil)
     Returns the names of the directories.
 
-    See also ((<show>)).
+    See also ((<ls>)).
 
     ARGUMENTS
     * ((|path|)) (nil or String): if nil, the method is applied to the
@@ -249,7 +250,7 @@ directory and can be changed by ((<GDir.cd>)).
 ---list_dirs_v(path=nil)
     Verbose version of ((<list_dirs>)), showing size and mtime like 'ls -l'.
 
-    See also ((<show_v>)).
+    See also ((<ls_l>)).
 
     ARGUMENTS
     * See ((<list_dirs>)).
@@ -278,7 +279,7 @@ directory and can be changed by ((<GDir.cd>)).
     Verbose version of ((<list_data>)), showing shape, long_name,
     and units.
 
-    See also ((<show_v>)).
+    See also ((<ls_l>)).
 
     ARGUMENTS
     * See ((<list_data>)).
@@ -309,7 +310,7 @@ directory and can be changed by ((<GDir.cd>)).
 ---list_texts_v(path=nil)
     Verbose version of ((<list_texts>)), showing size and mtime like 'ls -l'.
 
-    See also ((<show_v>)).
+    See also ((<ls_l>)).
 
     ARGUMENTS
     * See ((<list_texts>)).
@@ -317,7 +318,7 @@ directory and can be changed by ((<GDir.cd>)).
     RETURN VALUE
     * an Array of String
 
----show(path=nil)
+---ls(path=nil)
     Prints the results of ((<list_dirs>)), ((<list_data>)), and 
     ((<list_texts>)) on the standard output.
 
@@ -330,21 +331,14 @@ directory and can be changed by ((<GDir.cd>)).
 ---each_data
     Iterator for each GPhys under self.
 
----ls(path=nil)
-    Aliased to ((<show>))
-
----show_v(path=nil)
-    Verbose version of ((<show>)).
+---ls_l(path=nil)
+    Verbose version of ((<ls>)).
     Prints the results of ((<list_dirs_v>)), ((<list_data_v>)), and 
     ((<list_texts_v>)) on the standard output.
 
     RETURN VALUE
     * nil
 
----ls_v(path=nil)
-    Aliased to ((<show_v>))
-
-
 ---mtime
     Returns the last modified time.
 
@@ -375,7 +369,8 @@ directory and can be changed by ((<GDir.cd>)).
 
 =end
 
-require "numru/gphys"    # used in GFile
+require "numru/gphys"
+require "numru/htdir"
 
 module NumRu
 
@@ -388,16 +383,34 @@ module NumRu
 
     @@cwd = nil        # current working directory
 
+    HtDir.dods_interpret = true
+
     def initialize(path)
-      path = '/' + path if /^\// !~ path      # to always start with '/'
-      path = File.expand_path( path )
-      abspath = @@top.sub(/\/$/,'')+path.sub(/\/$/,'')
-      @path = abspath.sub(@@top_pat,'') + '/'
-      @abspath = abspath + '/'
+      http = false
+      if /^http/ =~ path
+	http = true
+	abspath = path.sub(/\/+$/,'')
+	@path = @abspath = ( abspath + '/' )
+      elsif /^http/ =~ @@top
+	http = true
+	abspath = @@top + path.sub(/\/+$/,'')
+	abspath = File.expand_path( '/'+abspath ).sub(/^\//,'').sub(/^http:\//,'http://')  # to clean up the path
+	@path = @abspath = ( abspath + '/' )
+      else
+	path = '/' + path if /^\// !~ path      # to always start with '/'
+	path = File.expand_path( path )         # to clean up the path
+	abspath = @@top.sub(/^(\/.*)\/$/,'\1')+path.sub(/\/+$/,'')
+	@path = abspath.sub(@@top_pat,'') + '/'
+	@abspath = abspath + '/'
+      end
       ftype = __ftype(abspath)
       case ftype
       when "directory"
-	@dir = Dir.new(abspath)
+	if http
+	  @dir = HtDir.new(abspath)
+	else
+	  @dir = Dir.new(abspath)
+	end
 	@file = nil
       when "file"
 	if (file_class = GPhys::IO::file2file_class( abspath ))
@@ -419,7 +432,11 @@ module NumRu
       alias open new
 
       def top=(top)
-	top = File.expand_path( top )   # to absolute path
+	if /^http:\/\// =~ top
+	  top = top.sub(/\/+$/,'')
+	else
+	  top = File.expand_path( top )   # to absolute path
+	end
         ### top.untaint
         @@top_pat =  Regexp.new('^'+top)
 	@@top = top + '/'
@@ -460,13 +477,14 @@ module NumRu
 	end
       end
 
+      alias chdir cd
       alias cwd= cd
 
       [ ## 'mtime','ctime','atime',
         ## 'size','mtime_like_ls_l',
        '[]','data','text',
        'list_dirs','list_dirs_v','list_data','list_data_v',
-       'list_texts','list_texts_v','show','ls','show_v','ls_l'
+       'list_texts','list_texts_v','ls','ls_l'
       ].each do |method|
 	eval <<-EOS
 	  def #{method}(*args)
@@ -694,6 +712,9 @@ module NumRu
 	self.dir(path).list_dirs
       else
 	if @dir
+	  if /^http:\/\// =~ @abspath
+	    return self.list_dirs
+	  end
 	  list = []
 	  @dir.rewind
 	  @dir.collect{|x| x}.sort.each{|fnm|
@@ -772,6 +793,9 @@ module NumRu
 	self.dir(path).list_texts
       else
 	if @dir
+	  if /^http:\/\// =~ @abspath
+	    return self.list_texts
+	  end
 	  list = []
 	  @dir.rewind
 	  @dir.collect{|x| x}.sort.each{|fnm|
@@ -892,20 +916,29 @@ module NumRu
 
     def __ftype(path, _depth=0)
       # Same as File.ftype, but traces symbolic links
-      ftype = File.ftype(path)
-      if ftype == "link"
-	if _depth < 10   # == max_depth
-          begin
-	    lkpath = File.readlink(path)
-	    unless /^\// === lkpath
-	      lkpath = File.dirname(path)+'/'+lkpath
-	    end
-	    ftype = __ftype( lkpath, _depth+1 )
-	  rescue
-	    nil    # possibly a link to non-existent file
-	  end
+
+      if /^http/ =~ path
+	if /\.(nc|ctl|ctrl|grib|cdf|hdf|dat|bin|gz|jg)$/i =~ path
+	  ftype = 'file'
 	else
-	  nil    # Max depth exeeded: Link too long (possibly circular)
+	  ftype = 'directory'
+	end
+      else
+	ftype = File.ftype(path)
+	if ftype == "link"
+	  if _depth < 10   # == max_depth
+	    begin
+	      lkpath = File.readlink(path)
+	      unless /^\// === lkpath
+		lkpath = File.dirname(path)+'/'+lkpath
+	      end
+	      ftype = __ftype( lkpath, _depth+1 )
+	    rescue
+	      nil    # possibly a link to non-existent file
+	    end
+	  else
+	    nil    # Max depth exeeded: Link too long (possibly circular)
+	  end
 	end
       end
       ftype
@@ -991,4 +1024,15 @@ if __FILE__ == $0
   print "*(test)* Searching all text files under the top dir...\n"
   find_txt(gdir).each{|txt| print txt.path,"\n"}
 
+  print "\n***(test)*** DODS access \n"
+  gdir = GDir.new('http://davis-dods.rish.kyoto-u.ac.jp/cgi-bin/nph-dods/jmadata/gpv/latest/gpv')
+  p gdir.ls
+  gd2 = gdir.dir('latest/')
+  p gd2.ls_l
+  gd3 = gd2.dir('MSM00S.nc/')
+  p gd3.ls_l
+  GDir.top = 'http://davis-dods.rish.kyoto-u.ac.jp/cgi-bin/nph-dods/jmadata/gpv/latest/gpv'
+  gdir = GDir.new('.')
+  g2 = GDir.new('latest')
+  p gdir.ls,g2.ls
 end
