@@ -260,6 +260,12 @@ simulation. The 3rd is not physical and may not be considered as
     * an obejct with the same class as ary, or of a Numeric 
       class if ary is 1D.
 
+---integ_weight
+    Returns the integration weight (whose default is nil).
+
+---integ_weight=(wgt)
+    Sets the integration weight (whose default is nil).
+
 ---average(ary,dim)
     Similar to ((<integrate>)), but does averaging
 
@@ -269,6 +275,12 @@ simulation. The 3rd is not physical and may not be considered as
     RETURN VALUE
     * see ((<integrate>))
 
+---average_weight
+    Returns the integration weight (whose default is nil).
+
+---average_weight=(wgt)
+    Sets the integration weight (whose default is nil).
+
 ---draw_positive
     Returns the direction to plot the axis, which relies on the 
     VArray#axis_draw_positive method.
@@ -693,7 +705,7 @@ module NumRu
       @@operations = ["integrate","average"]
 
       def integrate(ary,dim)
-	 if !@integ_wieght; _set_default_integ_weight; end
+	 if !@integ_weight; _set_default_integ_weight; end
 	 sh = (0...ary.rank).collect{|i| (i==dim) ? @integ_weight.length : 1 }
 	 mn = sprintf("%g", ( UNumeric===(a=@pos.min) ? a.val : a) )
          mx = sprintf("%g", ( UNumeric===(a=@pos.max) ? a.val : a) )
@@ -701,6 +713,9 @@ module NumRu
 	          "integrated  "+@name+":#{mn}..#{mx}" ]
       end
 
+      def integ_weight; @integ_weight; end
+      def integ_weight=(wgt); @integ_weight=wgt; end
+
       def average(ary,dim)
 	 if !@avg_weight; _set_default_avg_weight; end
 	 sh = (0...ary.rank).collect{|i| (i==dim) ? @avg_weight.length : 1 }
@@ -710,6 +725,9 @@ module NumRu
 	          "averaged  "+@name+":#{mn}..#{mx}" ]
       end
 
+      def average_weight; @avg_weight; end
+      def average_weight=(wgt); @avg_weight=wgt; end
+
       def draw_positive
 	# Returns the direction to plot the axis
 	# * true: axis should be drawn in the increasing order(to right/upward)
@@ -819,9 +837,12 @@ if $0 == __FILE__
    p z.val
    p axpt.average(z,0), axcel_c.average(z,0)
    p z.sum(0)/10
+   print "### avg/integ ###\n"
    p  axpt.average(w,0), axcel_c.average(w,0), 
       axpt.integrate(w,0), axcel_c.integrate(w,0), 
       axcel_b.integrate(w2,0)
+   axpt.integ_weight = NArray.sfloat(axpt.length).fill!(0.5)
+   p  'with artificial integ_weight:', axpt.integrate(w,0)
    # axcel.set_default_algorithms  # this is to fail
    print "////////\n"
    p axpt[1..3].pos.val
