@@ -633,15 +633,15 @@ module NumRu
       def coerce(other)
 	case other
 	when Numeric
-	  na_other = self.data.val.fill(other)   # Not efficient!
-           #developpers memo: perhaps need to let VArray know GPhys to avoid it
-           #XJ[rank[ GPhys `邪ƓB
-           #NArrayScalarł shape  [1] ԂĂ܂B
-	  va_other, = self.data.coerce(na_other)
-	  c_other = GPhys.new( @grid, va_other )
+	  ##na_other = self.data.val.fill(other)   # Not efficient!
+	  va_other, = self.data.coerce(other)
+	  c_other = GPhys.new( @grid[ *([0..0]*self.rank) ], 
+			       va_other.reshape!( *([1]*self.rank) ) )
+	  c_other.put_att('units',nil)   # should be treated as such, not 1
 	when Array, NArray
 	  va_other, = self.data.coerce(other)
 	  c_other = GPhys.new( @grid, va_other )
+	  c_other.put_att('units',nil)   # should be treated as such, not 1
 	when VArray
 	  c_other = GPhys.new( @grid, other )
 	else
@@ -705,10 +705,12 @@ module NumRu
                if myself.is_a?(GPhys)
 		 if other.is_a?(GPhys)
 		   vary = myself.data#{f} other.data
+                   newgrid = myself.grid.merge(other.grid)
 		 else
 		   vary = myself.data#{f} other
+                   newgrid = myself.grid_copy
 		 end
-		 GPhys.new( myself.grid.copy, vary )
+		 GPhys.new( newgrid, vary )
 	       else
 		 if other.is_a?(GPhys)
 		   vary = myself#{f} other.data
