@@ -142,7 +142,8 @@ module NumRu
 	when *@@grib_pattern
           return GRIB
 	when String
-          return nil until File.exist?(file)
+	  return NETCDF if /^http:\/\// =~ file   # assume a DODS URL
+          return nil unless File.exist?(file)
           return NETCDF if NetCDF_IO.is_a_NetCDF?(file)
           return GRADS if GrADS_IO.is_a_GrADS?(file)
           return GRIB if Grib_IO.is_a_Grib?(file)
