@@ -329,7 +329,7 @@ module NumRu
 	    bare_index[i]=true
 	    na = NArray.float(ncvar0.shape_current[i]).indgen!
 	    axpos = VArray.new( na )
-            axpos.name = "axis_#{i}"          # added by S. OTSUKA
+            axpos.name = axposnames[i]         # added by S. OTSUKA
 	  end
 	  cell_center, cell_bounds_name = convention::cell_center?( axpos )
 	  cell_bounds, cell_center_name = convention::cell_bounds?( axpos )
