@@ -383,10 +383,20 @@ module NumRu
             end
           end
         end
-        params || raise("parameter table version #{version} has not defined yet ")
-        para = params[nid] || raise("parameter ID #{nid} in version #{version} has not defined yet ")
-        para = NAMES_UNITS[para] || raise("parameter ID #{nid} in version #{version} has not defined yet ")
-        return para
+        if params
+          if para_id = params[nid]
+            if para = NAMES_UNITS[para_id]
+              return para
+            else
+              $stderr.printf "parameter ID #{nid} in version #{version} has not defined yet\n"
+            end
+          else
+            $stderr.printf "parameter ID #{nid} in version #{version} has not defined yet\n"
+          end
+        else
+          $stderr.printf "parameter table version #{version} has not defined yet\n"
+        end
+        return ["unknown (#{nid})", nid.to_s, "-", nil]
       end
       def cid
         return str2uint(@pds[1,1])
@@ -481,8 +491,9 @@ module NumRu
       def sname
         zid = str2uint( @pds[6,1] )
         sn = param[1]
-        zn = Z_TYPES[zid][1]
-        if zn.nil?||zn=="level"
+        zt = Z_TYPES[zid]
+        zn = zt ? zt[1] : zid.to_s
+        if zn=="level"
           return sn
         else
           return sn+"_"+zn
@@ -492,7 +503,14 @@ module NumRu
         return param[2]
       end
       def z_type
-        return Z_TYPES[ str2uint( @pds[6,1] ) ][0]
+        zid = str2uint( @pds[6,1] )
+        zt = Z_TYPES[zid]
+        if zt
+          return zt[0]
+        else
+          $stderr.printf "z type (#{zid}) is not defined yet\n"
+          return zid.to_s
+        end
       end
       def set_z_id(id)
         @pds[6..6] = uint2str(id,1)
@@ -500,7 +518,13 @@ module NumRu
       end
       alias :z_id= :set_z_id
       def z_sname
-        return zn = Z_TYPES[ str2uint( @pds[6,1] ) ][1]
+        zid = str2uint( @pds[6,1] )
+        if zn = Z_TYPES[zid]
+          return zn[1]
+        else
+          $stderr.printf "z type (#{zid}) is not defined yet\n"
+          return "unknown_#{zid}"
+        end
       end
       def z_value
         type = str2uint( @pds[6,1] )
@@ -1167,9 +1191,13 @@ module NumRu
               mask = map[*index]
               index[1].each{|j|
                 jj = j-index[1].first
-                sb = (j*nlon+index[0].first-map[true,0..jj-1].count_false)*nbits_pack
+                sb = j*nlon+index[0].first
+                sb = sb-map[true,0..jj-1].count_false if jj>0
+                sb = sb*nbits_pack
                 eb = sb+mask[true,j].count_true*nbits_pack
-                var[mask[true,j].where,jj] = get_value(@sgm.file,@pos+8,sb,eb,nbits_pack,nstep)
+                if sb!=eb
+                  var[mask[true,j].where,jj] = get_value(@sgm.file,@pos+8,sb,eb,nbits_pack,nstep)
+                end
               }
             else
               var = NArray.float(*shape2)
@@ -1590,9 +1618,15 @@ module NumRu
         $stderr.printf("unit is not same: #{pds1.unit} != #{pds2.unit}\n")
           return false
         end
-        if pds1.z_type!=pds2.z_type
-          $stderr.printf("z type is not same: #{pds1.z_type} != #{pds2.z_type}\n")
-          return false
+        zt1 = pds1.z_type
+        zt2 = pds2.z_type 
+        if zt1 != zt2
+          if zt1.nil? || zt2.nil?
+            $stderr.printf("z type is not same: #{zt1 ? zt1 : "nil"} != #{zt2 ? zt2 : "nil"}\n")
+          else
+            $stderr.printf("z type is not same: #{zt1} != #{zt2}\n")
+            return false
+          end
         end
         if pds1.time_range!=pds2.time_range
           $stderr.printf("time range is not same: #{pds1.time_range} != #{pds2.time_range}\n")
@@ -1655,7 +1689,11 @@ module NumRu
             sgms.each{|sgm|
               zv = sgm.pds.z_value
               nz.times{|m|
-                z[m].push( zv[m]["value"] )
+                if zv[m]
+                  z[m].push( zv[m]["value"] )
+                else
+                  z[m].push(m)
+                end
               }
             }
             nz.times{|m|
