@@ -49,6 +49,7 @@ Z_TYPES = {
   7 => ["tropopause level", "trop"],
   8 => ["Nominal top of atmosphere", "topa"],
   9 => ["Sea bottom", "sbot"],
+  20 => ["isothermal level", "isot"],
   100 => ["isobaric level", "level"],
   101 => ["layer between two isobaric levels", "liso"],
   102 => ["mean sea level", "msl"],
@@ -65,6 +66,9 @@ Z_TYPES = {
   113 => ["isentropic (theta) level", "isen"],
   114 => ["layer between two isentropic levels", "lisn"],
   116 => ["layer between two isobaric surfaces above ground", "lisg"],
+  117 => ["potential vorticity surface", "pvs"],
+  119 => ["ETA level", "eta"],
+  120 => ["layer between two ETA levels", "leta"],
   121 => ["layer between two isobaric surfaces (high precision)", "lish"],
   125 => ["Height level above ground (heigh precision)", "fhgh"],
   128 => ["layer between two sigma levels (high precision)", "lsh"],
@@ -72,9 +76,21 @@ Z_TYPES = {
   160 => ["depth below sea level", "dbs"],
   200 => ["entire atmosphere considered as a single layer", "atm"],
   201 => ["entire ocean considered as single layer", "ocn"],
+  204 => ["highest tropospheric freezing level", "htfl"],
+  212 => ["low cloud bottom", "lcb"],
+  213 => ["low cloud top", "lct"],
+  214 => ["low cloud layer", "lcl"],
+  222 => ["middle cloud bottom", "mcb"],
+  223 => ["middle cloud top", "mct"],
+  224 => ["middle cloud layer", "mcl"],
+  232 => ["high cloud bottom", "hcb"],
+  233 => ["high cloud top", "hct"],
+  234 => ["high cloud layer", "hcl"],
   242 => ["convect cloud bottom", "ccb"],
   243 => ["convect cloud top", "cct"],
   244 => ["convect cloud layer", "ccl"],
+  246 => ["maximum equivalent potential temperature pressure", "meptp"],
+  247 => ["equilibrium level height", "elh"],
 }
 Z_LEVELS = {
   100 => [{"name"=>"pressure","units"=>"hPa"}],
@@ -100,6 +116,10 @@ Z_LEVELS = {
     {"name"=>"475K minus theta of bottom","units"=>"K"}],
   116 => [{"name"=>"pressure of top above ground", "units"=>"hPa"},
     {"name"=>"pressure of bottom above ground", "units"=>"hPa"}],
+  117 => [{"name"=>"PV unit", "units"=>"1/1000000Km2/kg/s"}],
+  119 => [{"name"=>"ETA value", "units"=>"1/10000"}],
+  120 => [{"name"=>"ETA level of top", "units"=>"1/100"},
+    {"name"=>"ETA level of bottom", "units"=>"1/100"}],
   121 => [{"name="=>"1100hPa minus pressure of top","units"=>"hPa"},
     {"name"=>"1100hPa minus pressure of bottom","units"=>"hPa"}],
   125 => [{"name"=>"height","units"=>"cm"}],
@@ -107,7 +127,7 @@ Z_LEVELS = {
     {"name"=>"1.1 minus sigma of bottom","units"=>"1/1000"}],
   141 => [{"name"=>"pressure of top","units"=>"kPa"},
     {"name"=>"pressure of bottom","units"=>"kPa"}],
-  160 => {"name"=>"depth","units"=>"m"}
+  160 => [{"name"=>"depth","units"=>"m"}],
 }
 TIME_UNITS = {
   0 => "minute",
@@ -287,6 +307,7 @@ PARAM_LFT_X = 2131
 PARAM_4LFTX = 2132
 PARAM_VW_SH = 2136
 PARAM_SOILW = 2144
+PARAM_CLWMR = 2153
 PARAM_O3MR = 2154
 PARAM_CIN = 2156
 PARAM_CAPE = 2157
@@ -611,7 +632,7 @@ NAMES_UNITS = {
 #150	COVMZ	m2/s2		Covariance between meridional and zonal components of the wind. Defined as [uv]-[u][v], where "[]" indicates the mean over the indicated time span.		
 #151	COVTZ1	K*m/s		Covariance between temperature and zonal component of the wind. Defined as [uT]-[u][T], where "[]" indicates the mean over the indicated time span.		
 #152	COVTM	K*m/s		Covariance between temperature and meridional component of the wind. Defined as [vT]-[v][T], where "[]" indicates the mean over the indicated time span.		
-#153	CLWMR	Kg/kg		Cloud water		
+  PARAM_CLWMR => ["Cloud water", "CLWMR", "Kg/kg", nil],
   PARAM_O3MR => ["Ozone mixing ratio", "O3MR", "Kg/kg", nil],
 #155	GFLUX	W/m2		Ground Heat Flux		
   PARAM_CIN => ["Convective inhibition", "CIN", "J/kg", nil],
@@ -1038,6 +1059,7 @@ PARAMS_NCEP_2 = {   #incomplete
   132 => PARAM_4LFTX,
   136 => PARAM_VW_SH,
   144 => PARAM_SOILW,
+  153 => PARAM_CLWMR,
   154 => PARAM_O3MR,
   156 => PARAM_CIN,
   157 => PARAM_CAPE,
