@@ -90,6 +90,17 @@ A class to handle discretized grids of physical quantities.
     RETURN VALUE
     * a Grid
 
+---merge(other)
+    merge two grids by basically using copies of self's axes but
+    using the other's if the length in self is 1 and 
+    the length in the other is longer
+
+    ARGUMENTS
+    * other (Grid)
+
+    RETURN VALUE
+    * a Grid
+
 ---shape
     Returns the shape of self.
 
@@ -323,6 +334,26 @@ module NumRu
 	 out
       end
 
+      def merge(other)
+	# merge two grids by basically using copies of self's axes but
+	# using the other's if the length in self is 1 and 
+        # the length in the other is longer
+	if self.rank != other.rank
+	  raise "ranks do not agree (self:#{self.rank} vs other:#{other.rank})"
+	end
+	axes = Array.new
+	for i in 0...self.rank
+	  if @axes[i].length == 1 and other.axis(i).length > 1
+	    axes[i] = other.axis(i)
+	  else
+	    axes[i] = @axes[i]
+	  end
+	end
+	out = Grid.new( *axes )
+	out.set_lost_axes( @lost_axes.dup + other.lost_axes )
+	out
+      end
+
       def shape
 	 @axes.collect{|ax| ax.length}
       end
@@ -340,7 +371,7 @@ module NumRu
 	       raise ArgumentError,"# of the args does not agree with the rank"
 	    end
 	    axes = Array.new
-	    lost = self.lost_axes.dup  #Array.new
+	    lost = self.lost_axes  #Array.new
 	    for i in 0...rank
 	       ax = @axes[i][slicer[i]]
 	       if ax.is_a?(Axis)      # else its rank became zero (lost)
@@ -506,9 +537,10 @@ module NumRu
       def ax_dim(dim_or_dimname)
 	 if dim_or_dimname.is_a?(Integer)
 	    dim = dim_or_dimname
-	    if dim < 0 || dim >= rank
+	    if dim < -rank || dim >= rank
 	       raise ArgumentError,"rank=#{rank}: #{dim}th grid does not exist"
 	    end
+	    dim += rank if dim < 0
 	 else
 	    dim = @axnames.index(dim_or_dimname)
 	    if !dim
