@@ -222,6 +222,9 @@ NOMENCLATURE
 ---transpose(*dims)
     Transpose. Argument specification is as in NArray.
 
+---reshape(*shape)
+    Reshape. Argument specification is as in NArray.
+
 ---axis_draw_positive
     Returns the direction to plot the axis (meaningful only if self is a
     coordinate variable.) 
@@ -554,6 +557,10 @@ These methods returns a NArray (not a VArray).
 	VArray.new( val.transpose(*dims), attr_copy, name )
       end
 
+      def reshape(*shape)
+	VArray.new( val.reshape(*shape), attr_copy, name )
+      end
+
       def axis_draw_positive
 	positive = attr['positive']
 	case positive
@@ -604,7 +611,7 @@ These methods returns a NArray (not a VArray).
       Math_funcs = Math_funcs_nondim + Math_funcs_radian + ["sqrt"]
 
       Binary_operators_Uop   = ["*","/","**", ".mul!",".div!"]
-      Binary_operators_Uconv = ["+","-",".add!",".sub!"]
+      Binary_operators_Uconv = ["+","-",".add!",".sbt!"]
       Binary_operators_Unone = ["%",".mod!",".imag="]
       Binary_operators = Binary_operators_Uop + 
 	                 Binary_operators_Uconv +
@@ -682,12 +689,24 @@ These methods returns a NArray (not a VArray).
 	 def #{f.delete(".")}(other)
 	    case other
             when VArray, UNumeric
-               ary = self.val#{f}(other.val)
+	       vl = self.val
+	       vr = other.val
+	       begin
+		 ary = vl#{f}(vr)
+	       rescue
+		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
+	       end
 	       va = VArray.new( ary, self.attr_copy, self.name )
 	       va.units= self.units#{f}(other.units)
                va
 	    when Numeric, NArray, NArrayMiss, Array
-	       ary = self.val#{f}(other)
+	       vl = self.val
+	       vr = other
+	       begin
+		 ary = vl#{f}(vr)
+	       rescue
+		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
+	       end
 	       va = VArray.new( ary, self.attr_copy, self.name )
 	       if "#{f}" == "**" 
 		 va.units= self.units#{f}(other)
@@ -705,10 +724,28 @@ These methods returns a NArray (not a VArray).
 	 def #{f.delete(".")}(other)
 	    case other
             when VArray, UNumeric
-               ary = self.val#{f}( other.units.convert2(other.val,units) )
-	       VArray.new( ary, self.attr_copy, self.name )
+               if self.get_att('units')
+		 # self have non nil units
+		 oval = other.units.convert2(other.val,self.units)
+		 uni = self.units
+	       else
+		 oval = other.val
+		 uni = other.units
+	       end
+               begin
+                 ary = self.val#{f}( oval )
+               rescue
+                 ary = NArrayMiss.to_nam(self.val)#{f}( oval )
+               end
+	       va = VArray.new( ary, self.attr_copy, self.name )
+	       va.units = uni
+	       va
 	    when Numeric, NArray, NArrayMiss, Array
-	       ary = self.val#{f}(other)
+               begin
+		 ary = self.val#{f}(other)
+               rescue
+		 ary = NArrayMiss.to_nam(self.val)#{f}(other)
+	       end
 	       VArray.new( ary, self.attr_copy, self.name )
             else
                c_me, c_other = other.coerce(self)
@@ -722,10 +759,22 @@ These methods returns a NArray (not a VArray).
 	 def #{f.delete(".")}(other)
 	    case other
             when VArray, UNumeric
-               ary = self.val#{f}(other.val)
+	       vl = self.val
+	       vr = other.val
+	       begin
+		 ary = vl#{f}(vr)
+	       rescue
+		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
+	       end
 	       VArray.new( ary, self.attr_copy, self.name )
 	    when Numeric, NArray, NArrayMiss, Array
-	       ary = self.val#{f}(other)
+	       vl = self.val
+	       vr = other
+	       begin
+		 ary = vl#{f}(vr)
+	       rescue
+		 ary = NArrayMiss.to_nam(vl)#{f}(vr)
+	       end
 	       VArray.new( ary, self.attr_copy, self.name )
             else
                c_me, c_other = other.coerce(self)
